# Austrian 
Ідея і стартова реалізація завдячує роботі `d3m0`.

Бібліотека для перетворення повнотекстової назви або коментаря до об'єкта на код sidc стандарту app6d

## Як працювати зараз?

Запускає
```
from text_to_sidc import austrian

austrian.UnitDesignator.calculate_icon("танк")
//'30062000001103000000'
```        